ADSBMessageKind

Enum ADSBMessageKind 

pub enum ADSBMessageKind {
    AircraftIdentification {
        emitter_category: u8,
        callsign: String,
    },
    AirbornePosition {
        altitude: u16,
        cpr_frame: CPRFrame,
    },
    AirborneVelocity {
        heading: f64,
        ground_speed: f64,
        vertical_rate: i16,
        vertical_rate_source: VerticalRateSource,
    },
}
Kind of ADSB message.

Variants



AircraftIdentification

Aicraft identification and category message (TC 1-4)

Fields

emitter_category: u8

Emitter category used to determine the type of aircraft

callsign: String

Aircraft callsign



AirbornePosition

Airborne position message (TC 9-18)

Fields

altitude: u16

Altitude in feet

cpr_frame: CPRFrame

Odd or even frame encoding position information in CPR format



AirborneVelocity

Airborne velocity message (TC 19)

Fields

heading: f64

Heading in degrees

ground_speed: f64

Ground speed in knots

vertical_rate: i16

Vertical rate in feet per minute, positive values indicate an aircraft is climbing and negative values indicate it is descending

vertical_rate_source: VerticalRateSource

Source for vertical rate information